@@ -3,11 +3,18 @@
 #' @param path Path to a file to save the graph into
 #' @return Run for its side-effects
 #' @export
+#' @family graphs i/o
+#' @examples
+#' graph <- graph_builder() |>
+#'   add_edge("A", "B") |>
+#'   build_directed()
+#'
+#' graph_to_bin(graph)
 graph_to_bin <- function(graph, path) {
   if (missing(path)) {
-    return(graph$to_bin_mem())
+    return(throw_if_error(graph$to_bin_mem()))
   }
-  graph$to_bin_disk(path)
+  throw_if_error(graph$to_bin_disk(path))
 }
 
 #' @title Read the graph from a binary blob
@@ -16,25 +23,38 @@ graph_to_bin <- function(graph, path) {
 #' @param type The type of graph the JSON represents
 #' @return A graph object
 #' @export
+#' @family graphs i/o
+#' @examples
+#' bin <- graph_builder() |>
+#'   add_edge("A", "B") |>
+#'   build_directed() |>
+#'   graph_to_bin()
+#' bin
+#'
+#' graph_from_bin(bin = bin)
 graph_from_bin <- function(path, bin, type = c("directed", "dag")) {
   if (!type[1] %in% c("directed", "dag")) {
     rlang::abort("Invalid argument `type`")
   }
   if (!missing(bin)) {
     return(
-      switch(
-        type[1],
-        "directed" = DirectedGraph$from_bin_mem(bin),
-        "dag" = DirectedAcyclicGraph$from_bin_mem(bin)
+      throw_if_error(
+        switch(
+          type[1],
+          "directed" = DirectedGraph$from_bin_mem(bin),
+          "dag" = DirectedAcyclicGraph$from_bin_mem(bin)
+        )
       )
     )
   }
   if (missing(path)) {
     rlang::abort("Must provide `path` or `bin` arguments")
   }
-  switch(
-    type[1],
-    "directed" = DirectedGraph$from_bin_disk(path),
-    "dag" = DirectedAcyclicGraph$from_bin_disk(path)
+  throw_if_error(
+    switch(
+      type[1],
+      "directed" = DirectedGraph$from_bin_disk(path),
+      "dag" = DirectedAcyclicGraph$from_bin_disk(path)
+    )
   )
 }
