@@ -6,8 +6,14 @@ test_that("get roots directed", {
     build_directed()
 
 
-  expect_equal(get_all_roots(graph), c("A", "Z"))
-  expect_equal(get_roots_over(graph, "D"), c("A"))
+  expect_equal(
+    as.character(get_all_roots(graph)),
+    c("A", "Z")
+  )
+  expect_equal(
+    as.character(get_roots_over(graph, "D")),
+    c("A")
+  )
 })
 
 test_that("get leaves directed", {
@@ -18,8 +24,14 @@ test_that("get leaves directed", {
     add_path(c("Z", "B", "H")) |>
     build_directed()
 
-  expect_equal(get_all_leaves(graph), c("C", "H"))
-  expect_equal(get_leaves_under(graph, "D"), c("C"))
+  expect_equal(
+    as.character(get_all_leaves(graph)),
+    c("C", "H")
+  )
+  expect_equal(
+    as.character(get_leaves_under(graph, "D")),
+    c("C")
+  )
 })
 
 test_that("get roots acyclic", {
@@ -30,8 +42,14 @@ test_that("get roots acyclic", {
     build_acyclic()
 
 
-  expect_equal(get_all_roots(graph), c("A", "Z"))
-  expect_equal(get_roots_over(graph, "D"), c("A"))
+  expect_equal(
+    as.character(get_all_roots(graph)),
+    c("A", "Z")
+  )
+  expect_equal(
+    as.character(get_roots_over(graph, "D")),
+    c("A")
+  )
 })
 
 test_that("get leaves acyclic", {
@@ -42,6 +60,12 @@ test_that("get leaves acyclic", {
     add_path(c("Z", "B", "H")) |>
     build_acyclic()
 
-  expect_equal(get_all_leaves(graph), c("C", "H"))
-  expect_equal(get_leaves_under(graph, "D"), c("C"))
+  expect_equal(
+    as.character(get_all_leaves(graph)),
+    c("C", "H")
+  )
+  expect_equal(
+    as.character(get_leaves_under(graph, "D")),
+    c("C")
+  )
 })
